goroutineid

package module
v0.0.0-...-aa62e01 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 25, 2024 License: GPL-3.0 Imports: 3 Imported by: 2

README

goroutine id can be used for creating reentrant locks

better ways to get id may be available in future

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetCurrentGoId_byRuntimeStack

func GetCurrentGoId_byRuntimeStack() (uint64, error)

Types

This section is empty.

Jump to